Module endpoint

Module endpoint 

Endpoint configuration and socket ownership.

This module owns the UDP socket used by an endpoint. Packet driving is intentionally kept separate from socket binding so a server cannot report that it is listening before the operating system has accepted the bind.

Structs

ClientConfig
Configuration for a client endpoint.
ClientConfigBuilder
Builder for ClientConfig.
Connecting
An ongoing connection attempt.
Endpoint
A QUIC endpoint.
EndpointConfig
Configuration for an endpoint.
EndpointStats
Statistics about an endpoint.
Incoming
An incoming connection attempt.
ServerConfig
Configuration for a server endpoint.
ServerConfigBuilder
Builder for ServerConfig.
TransportConfig
Transport settings shared by all connections (RFC 9000 18.2).