Endpoint

Struct Endpoint 

pub struct Endpoint { /* private fields */ }
A QUIC endpoint.

Implementations

Source

impl Endpoint

pub async fn bind(addr: SocketAddr) -> Result<Self>

Creates a new endpoint bound to a local socket address.

pub async fn server( server_config: ServerConfig, addr: SocketAddr, ) -> Result<Self>

Binds a server endpoint using the supplied TLS and transport settings.

pub fn local_addr(&self) -> Result<SocketAddr>

Returns the address the operating system assigned to this endpoint.

pub async fn server_config(&self) -> Option<ServerConfig>

Returns this endpoint’s server configuration, if configured.

pub async fn set_server_config(&self, config: ServerConfig)

Hot-reloads the server configuration and TLS certificates.

pub async fn stats(&self) -> EndpointStats

Returns snapshot statistics for this endpoint.

pub async fn close(&self, _code: u64, _reason: &[u8])

Gracefully closes the endpoint and all active connections.

pub async fn wait_idle(&self)

Awaits until all active connections on this endpoint have closed.

pub async fn connect( &self, _addr: SocketAddr, _server_name: &str, ) -> Result<Connecting>

Connects to a remote endpoint.

pub async fn connect_with_config( &self, _addr: SocketAddr, _server_name: &str, _config: ClientConfig, ) -> Result<Connecting>

Connects to a remote endpoint using custom client configuration.

pub async fn connect_0rtt( &self, _addr: SocketAddr, _server_name: &str, ) -> Result<Connecting>

Connects to a remote endpoint with 0-RTT early data support (RFC 9001 4.2).

pub async fn accept(&self) -> Option<Incoming>

Accepts an incoming connection.