pub struct RecvStream { /* private fields */ }Expand description
A stream that can be read from.
Implementations
Sourceimpl RecvStream
impl RecvStream
Sourcepub fn set_priority(&mut self, priority: i32)
pub fn set_priority(&mut self, priority: i32)
Sets the stream priority for scheduling (RFC 9000 2.3).
Sourcepub async fn stop_sending(&mut self, error_code: u64) -> Result<()>
pub async fn stop_sending(&mut self, error_code: u64) -> Result<()>
Signals the peer to stop sending on this stream with an application error code (RFC 9000 19.5).
Sourcepub fn received_reset(&self) -> Option<u64>
pub fn received_reset(&self) -> Option<u64>
Returns the error code if the peer aborted this stream with a RESET_STREAM frame (RFC 9000 19.4).
Sourcepub async fn read_chunk(&mut self, max: usize) -> Result<Option<Bytes>>
pub async fn read_chunk(&mut self, max: usize) -> Result<Option<Bytes>>
Reads an individual contiguous chunk of data without copying into an intermediate buffer.
Sourcepub async fn read_chunks(&mut self, bufs: &mut [Bytes]) -> Result<usize>
pub async fn read_chunks(&mut self, bufs: &mut [Bytes]) -> Result<usize>
Reads into multiple buffers using vectored I/O.