pub struct SendStream { /* private fields */ }Expand description
A stream that can be written to.
Implementations
Sourceimpl SendStream
impl SendStream
Sourcepub fn set_priority(&mut self, priority: i32)
pub fn set_priority(&mut self, priority: i32)
Sets the stream priority for scheduling (RFC 9000 2.3).
Sourcepub async fn finish(&mut self) -> Result<()>
pub async fn finish(&mut self) -> Result<()>
Explicitly finishes the stream by sending a QUIC FIN (RFC 9000 19.8).
Sourcepub async fn reset(&mut self, error_code: u64) -> Result<()>
pub async fn reset(&mut self, error_code: u64) -> Result<()>
Abruptly terminates sending on this stream with an application error code (RFC 9000 19.4).
Sourcepub fn stopped(&self) -> Option<u64>
pub fn stopped(&self) -> Option<u64>
Returns the error code if the peer sent a STOP_SENDING frame (RFC 9000 19.5).
Sourcepub async fn write_chunks(&mut self, bufs: &[Bytes]) -> Result<usize>
pub async fn write_chunks(&mut self, bufs: &[Bytes]) -> Result<usize>
Scatter-gather writes multiple contiguous byte chunks to the stream.