Endpoint configuration and socket ownership.
This module owns the UDP socket used by an endpoint. Packet driving is intentionally kept separate from socket binding so a server cannot report that it is listening before the operating system has accepted the bind.
Structs
- Client
Config - Configuration for a client endpoint.
- Client
Config Builder - Builder for
ClientConfig. - Connecting
- An ongoing connection attempt.
- Endpoint
- A QUIC endpoint.
- Endpoint
Config - Configuration for an endpoint.
- Endpoint
Stats - Statistics about an endpoint.
- Incoming
- An incoming connection attempt.
- Server
Config - Configuration for a server endpoint.
- Server
Config Builder - Builder for
ServerConfig. - Transport
Config - Transport settings shared by all connections (RFC 9000 18.2).